@@ -524,6 +524,8 @@ GQuark regress_atest_error_quark (void);
 #define REGRESS_BOOL_CONSTANT TRUE
 #define REGRESS_G_GINT64_CONSTANT (G_GINT64_CONSTANT (1000))
 #define REGRESS_GUINT64_CONSTANT ((guint64) -1)
+#define REGRESS_GOOD_EXPR_CONSTANT (1 + 2 * (3 + 2) << 3 - 4 >> REGRESS_ATEST_ERROR_CODE2)
+#define REGRESS_BAD_EXPR_CONSTANT (1 + SOMETHING_UNDEFINED)
 
 typedef guint64 RegressTestTypeGUInt64;
 #define REGRESS_GUINT64_CONSTANTA ((RegressTestTypeGUInt64) -1)
@@ -623,6 +625,15 @@ struct _RegressTestStructF
 typedef struct _RegressTestSimpleBoxedA RegressTestSimpleBoxedA;
 typedef struct _RegressTestSimpleBoxedB RegressTestSimpleBoxedB;
 
+/**
+ * RegressTestSimpleBoxedA: (copy-func regress_test_simple_boxed_a_copy)
+ * @some_int:
+ * @some_int8:
+ * @some_double:
+ * @some_enum:
+ *
+ * ...
+ */
 struct _RegressTestSimpleBoxedA
 {
   gint some_int;
@@ -735,6 +746,11 @@ GType regress_test_boxed_c_get_type (void);
 _GI_TEST_EXTERN
 RegressTestBoxedC *regress_test_boxed_c_new (void);
 
+/**
+ * RegressTestBoxedD: (copy-func regress_test_boxed_d_copy)
+ *   (free-func regress_test_boxed_d_free)
+ *
+ */
 typedef struct _RegressTestBoxedD RegressTestBoxedD;
 
 
@@ -836,6 +852,12 @@ const char *regress_test_obj_get_string (RegressTestObj *obj);
 _GI_TEST_EXTERN
 void       regress_test_obj_emit_sig_with_obj (RegressTestObj *obj);
 
+_GI_TEST_EXTERN
+void       regress_test_obj_emit_sig_with_obj_full (RegressTestObj *obj);
+
+_GI_TEST_EXTERN
+void       regress_test_obj_emit_sig_with_gstrv_full (RegressTestObj *obj);
+
 _GI_TEST_EXTERN
 void       regress_test_obj_emit_sig_with_foreign_struct (RegressTestObj *obj);
 
